@import "../../../css/_mixins.scss";
@import "../../../css/_trx_addons.vars.scss";

/* Common slider's styles */
.slider_container {
	position:relative;
	overflow:hidden;
}
.slider_container:not(.inited) {
	&,
	& ~ .slider_pagination_wrap,
	& ~ .slider_controls_wrap {
		display:none;
	}
}

.slider_container.slider_overflow_visible,
.slider_container.slider_elastistack,
.slider_container.swiper-container-coverflow,
.slider_container.swiper-container-cube,
.slider_container.swiper-container-flip {
	overflow:visible;
}
.slider_outer {
	position:relative;
}
.slider_container .slider-slide {
	position:relative;
	/*max-height: 100vh;*/	/* Commented to correct height of slides in the stretched rows */
	@include bg-cover;
}
.slider_container:not(.slider_height_fixed) .slider-wrapper {
	@include flex-align-items(stretch);	/* Added to align height of the items with multiple columns or in the custom slides */
}
.slider_container:not(.slider_height_fixed) .slider-slide {
	height:auto;						/* Added to align height of the items with multiple columns or in the custom slides */
}
.slider_container.slider_height_fixed:not(.slider_direction_vertical) .slider-slide {
	height:100%;
}
.slider_container.slider_direction_vertical .slider-slide {
	min-height: 1px;
}

.slider_container[data-interval="0"]  {
	.swiper-wrapper,
	.swiper-slide,
	.slide_parallax_wrapper {
		transition-timing-function: linear !important;
	}
}

// Parallax wrapper
.slider_container.slider_with_parallax {
	.slider-slide {
		overflow: hidden;
	}
	.slide_parallax_wrapper {
		@include abs-cover;
		@include bg-cover;
		@include flex;
		@include flex-direction(column);
		@include flex-align-items(center);
		@include flex-justify-content(center);
	}
}

// Add min-height to avoid undesirable slide contraction
.slider_container.slider_type_bg:not(.slider_controller_container):not(.slider_multi),
.slider_container.slider_type_bg:not(.slider_controller_container):not(.slider_multi) .slider-slide {
	min-height: 180px;
}
.slider_container.slider_controls_side:not(.slider_controller_container):not(.slider_multi),
.slider_container.slider_controls_side:not(.slider_controller_container):not(.slider_multi) .slider-slide,
.slider_outer_controls_outside .slider_container:not(.slider_controller_container):not(.slider_multi),
.slider_outer_controls_outside .slider_container:not(.slider_controller_container):not(.slider_multi) .slider-slide {
	min-height: 3em;
}

.slider_container.slider_elastistack .slider-slide,
.slider_container.slider_type_text .slider-slide,
.slider_container.slider_type_bg .slider-slide,
.slider_container.slider_type_images .slider-slide {
	text-align: center;
	@include flex;
	@include flex-direction(column);
	@include flex-align-items(center);
	@include flex-justify-content(center);
}
.slider_container.slider_type_images .slider-slide {
	& > img,
	& > .slide_parallax_wrapper > img {
		//width: 100%;	// Slides with images as tags are used to display the logo (mostly) and should not be stretched
		max-width: 100%;
		height: auto;
	}
}
.slider_container .slider-slide {
	& > .slide_link,
	& > .slide_parallax_wrapper > .slide_link {
		display:block;
		@include abs-cover;
	}
	& > .trx_addons_video_player,
	& > .slide_parallax_wrapper > .trx_addons_video_player {
		display: block;
		@include box(100%, 100%);
	}
}

.slider_container .slide_info,
.slider_container .slide_info > *,
.slider_container .slide_content {
	@include transition-colors;
}

.slider_container.slider_type_text .slide_content {
	width: 100%;
}
.slider_container.slider_type_bg .slide_content,
.slider_container.slider_type_images .slide_content {
	position: relative;
	z-index: 2;
	color: #f0f0f0;
}
.slider_container .slide_info + .slide_content {
	margin-top: 0.5em;
}
.slider_container .slide_content p {
	margin:  0;
}

/* Slider style: Swap */
.slider_container.swiper-container-swap {
	.slider-slide {
		transition-property: transform, opacity;
	}
}

/* Slides with shadows
   Attention! Works only with CSS class 'slider_shadows'
   specified manually in Elementor Editor
   for the shortcode with slider */
.slider_shadows .slider_container,
.slider_container.slider_shadows {
	@include border-box;
	padding: 2em;

	.slider-slide {
		padding: 1.5em;
		background-color: #fff;
		@include box-shadow(0 0 30px 0 rgba(0,0,0,0.1));
	}
}

/* Info blocks in slides */
.slider_outer,
.slider_container {
	.slide_number {
		display: none;
	}
}
.slider_container .slide_info,
.slider_container .slide_content {
	position: relative;
	z-index: 2;
	text-align: center;
	padding: 0 3em;
	line-height: 1.3em;
	@include border-box;

}
.slider_container .slide_info.slide_info_large {
	padding: 2em;
	background-color:rgba(0,0,0,0.6);
}
.slider_container .slide_overlay,
.slider_container .slide_info.slide_info_large,
.slider_container .slide_info a {
	@include transition-all;
}
.slider_container.slider_type_bg .slide_info.slide_info_large .slide_title,
.slider_container.slider_type_images .slide_info.slide_info_large .slide_title,
.slider_container.slider_type_bg .slide_info.slide_info_large .slide_title a,
.slider_container.slider_type_images .slide_info.slide_info_large .slide_title a,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_date,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_date,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_cats,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_cats,
.slider_container.slider_type_bg .slide_info.slide_info_large:hover .slide_cats a,
.slider_container.slider_type_images .slide_info.slide_info_large:hover .slide_cats a {
	color: #ffffff;
}
.slider_container .slide_info.slide_info_large:hover {
	background-color:rgba(0,0,0,0.8);
}
.slider_container .slide_info.slide_info_large .slide_cats a {
	@include font(0.8667em, 1.7333em, 500);
	text-transform:uppercase;
}
.slider_container .slide_info.slide_info_large .slide_title {
	@include font(1.4em, 1.5em, 400);
	text-transform:uppercase;
	margin: 0.5em 0;
}
.slider_container .slide_info.slide_info_large .slide_date {
	font-size:0.9333em;
	font-style:italic;
}

.slider_container.slider_titles_center .slide_info:not(.slide_info_large),
.slider_container.slider_titles_center .slide_content {
	padding: 0;
}
.slider_container.slider_titles_center .slide_info_large {
	min-width: 50%;
	max-width: 75%;
}
.slider_container.slider_titles_lb .slider-slide,
.slider_container.slider_titles_rb .slider-slide,
.slider_container.slider_titles_bottom .slider-slide {
	@include flex-justify-content(flex-end);
}
.slider_container.slider_titles_lb .slider-slide:not(.with_content) .slide_info_small,
.slider_container.slider_titles_rb .slider-slide:not(.with_content) .slide_info_small,
.slider_container.slider_titles_bottom .slider-slide:not(.with_content) .slide_info_small,
.slider_container.slider_titles_lb .slide_content,
.slider_container.slider_titles_rb .slide_content,
.slider_container.slider_titles_bottom .slide_content {
	margin-bottom: 2em;
}
.slider_container.slider_titles_lb .slider-slide {
	@include flex-align-items(flex-start);
}
.slider_container.slider_titles_lb .slide_info,
.slider_container.slider_titles_lb .slide_content {
	text-align: left;
}
.slider_container.slider_titles_lb .slide_info_large {
	max-width: 50%;
}
.slider_container.slider_titles_rb .slider-slide {
	@include flex-align-items(flex-end);
}
.slider_container.slider_titles_rb .slide_info,
.slider_container.slider_titles_rb .slide_content {
	text-align: right;
}
.slider_container.slider_titles_rb .slide_info_large {
	max-width: 50%;
}

.slider_container .slide_info .slide_title {
	margin-top:0.4em;
}

.slider_titles_outside_wrap .slide_cats,
.slider_titles_outside_wrap .slide_subtitle {
	font-style: italic;
	letter-spacing:0;
}

.slider_container .slide_overlay {
	@include bg-mask(#000, 0.4, 1);
}
.slider_container .slider-slide:hover .slide_overlay {
	background-color:rgba(0,0,0,0.7);
}

.slider_container:not(.slider_type_text) .slide_info_small,
.slider_container.slider_multi:not(.slider_type_text) .slide_info_small {
	text-shadow: 1px 1px #000;
}
.slider_container.slider_pagination_pos_bottom.slider_pagination_bullets.slider_multi:not(.slider_titles_center) .slide_info,
.slider_container.slider_pagination_pos_bottom.slider_pagination_bullets:not(.slider_titles_center) .slide_info {
	margin-bottom: 3em;

	& + .slide_content {
		margin-top: -2.5em;
		margin-bottom: 3em;
	}
}
.slider_container.slider_pagination_pos_bottom.slider_pagination_custom.slider_multi:not(.slider_titles_center) .slide_info,
.slider_container.slider_pagination_pos_bottom.slider_pagination_custom:not(.slider_titles_center) .slide_info,
.slider_container.slider_pagination_pos_bottom.slider_pagination_fraction.slider_multi:not(.slider_titles_center) .slide_info,
.slider_container.slider_pagination_pos_bottom.slider_pagination_fraction:not(.slider_titles_center) .slide_info {
	margin-bottom: 4em;

	& + .slide_content {
		margin-top: -3.5em;
		margin-bottom: 4em;
	}
}
.slider_container.slider_multi .slide_title,
.slider_container .slide_info:not(.slide_info_large) .slide_title {
	font-size: 1.5385em;
	margin: 0.2em 0;
}
.slider_container.slider_multi:not(.slider_type_text) .slide_date,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_date {
	font-size: 0.8667em;
	font-style: italic;
	margin-bottom: 0.5em;
}

.slider_container.slider_multi:not(.slider_type_text) .slide_title,
.slider_container.slider_multi:not(.slider_type_text) .slide_title a,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_title,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_title a {
	color:#f0f0f0;
}
.slider_container.slider_multi:not(.slider_type_text) .slide_title a:hover,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_title a:hover,
.slider_container.slider_multi:not(.slider_type_text) .slide_cats a:hover,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_cats a:hover {
	color:#ffffff;
}
.slider_container.slider_multi:not(.slider_type_text) .slide_date,
.slider_container.slider_multi:not(.slider_type_text) .slide_cats,
.slider_container.slider_multi:not(.slider_type_text) .slide_cats a,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_date,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_cats,
.slider_container:not(.slider_type_text) .slide_info:not(.slide_info_large) .slide_cats a {
	color: #ccc;
}

.slider_container .video_play + .slide_info {
	display: none;
}
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play + .slide_info,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play + .slide_info + .slide_content,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play + .slide_content {
	@include transition-property(transform);
	pointer-events: none;
}
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play:hover + .slide_info,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play:hover + .slide_info + .slide_content,
.slider_container.slider_titles_center .trx_addons_video_player.with_cover.hover_play:hover + .slide_content {
	@include translateY(8em);
}


/* Titles outside */
.slider_outer.slider_outer_titles_outside {
	@include border-box;
	padding-bottom: 5rem;

	.slide_info .slide_number {
		//display: inline-block;
		vertical-align: top;
		@include abs-rc(1em);
		font-size: 2em;
	}
}
.slider_titles_outside_wrap {
	@include abs-lb(0, 0, 8);
	width: 100%;
	max-height: 4em;
	text-align: center;
}
.slider_titles_outside_wrap .slide_info {
	display:none;
}
.slider_titles_outside_wrap .slide_title {
	margin:0;
}

.slider_outer.slider_outer_titles_outside_top {
	padding-top: 8em;
	padding-bottom: 0;

	.slide_info .slide_number {
		display: inline-block;
	}
	.slider_titles_outside_wrap {
		@include abs-lt(0, 1.5em, 8);
		bottom: auto;
		max-height: 5em;
	}
}


/* Slider pagination */
.slider_container .swiper-pagination,
.slider_outer .swiper-pagination {
	display:block;
	text-align:center;
	z-index:9;
	color: #fff;
}
.slider_outer_pagination_pos_bottom_outside .swiper-pagination {
	position:static;
	display:block;
	text-align:center;
	margin-top: 1em;
	bottom: auto;
	left: auto;
}
.sc_item_slider .swiper-pagination-fraction {
	color: #333;
}

/* Pagination: Custom */
.swiper-pagination-custom .swiper-pagination-button {
	@include box(3em, 3em);
	border: 2px solid #ddd;
	@include bg-cover(center, #f7f7f7);
	opacity: 0.8;
	vertical-align:bottom;
	margin: 0 4px;
	display: inline-block;
	@include border-radius(4px);
}
.swiper-pagination-custom .swiper-pagination-button.swiper-pagination-button-active {
	opacity: 1;
	border-color: #efa758;
}
.slider_outer.slider_outer_pagination_pos_bottom.slider_outer_pagination_custom,
.slider_outer.slider_outer_pagination_pos_bottom_outside.slider_outer_pagination_custom {
	padding-bottom: 0 !important;
}
.slider_container.slider_pagination_pos_bottom .swiper-pagination-custom,
.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-custom,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
	left: 0;
	top: auto;
	bottom: 1em;
	@include box(100%, 3em, 3em);
	@include transform-none;
}
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-custom {
	left: auto;
	bottom: auto;
	position: static;
	margin-top: 1em;
}
.slider_container.slider_pagination_pos_left .swiper-pagination-custom,
.slider_container.slider_pagination_pos_right .swiper-pagination-custom {
	left: 1em;
	top: 50%;
	bottom: auto;
	@include box(auto, auto);
	@include translateY(-50%);
}
.slider_container.slider_pagination_pos_right .swiper-pagination-custom {
	right: 1em;
	left:auto;
}
.slider_container.slider_pagination_pos_left .swiper-pagination-button,
.slider_container.slider_pagination_pos_right .swiper-pagination-button {
	display: block;
	margin: 4px 0;
	@include box(2em, 2em);
}

/* Pagination: Bullets */
.slider_wrap .swiper-pagination-bullet {
	@include transition-property(background-color);
}
.slider_container .swiper-pagination-bullet,
.slider_outer .swiper-pagination-bullet {
	opacity: 0.8;
	vertical-align:bottom;
	border: 2px solid #f0f0f0;
	background-color: transparent;
	@include box(10px, 10px);
	@include bg-cover;
}
.slider_container .swiper-pagination-bullet-active,
.slider_outer .swiper-pagination-bullet-active {
	opacity: 1;
}
.slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets,
.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets {
	left: 0;
	top: auto;
	bottom: 1em;
	@include box(100%, 1.5em, 1.5em);
	@include transform-none;
}
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets,
.slider_container.slider_type_text.slider_pagination_pos_bottom .swiper-pagination,
.sc_item_slider.slider_outer_pagination_pos_bottom .swiper-pagination {
	left: auto;
	bottom: auto;
	position: static;
	margin-top: 1em;
}
.slider_container.slider_type_text.slider_pagination_pos_bottom .swiper-pagination {
	margin-top: 0.25em;
}
.slider_container.slider_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-bullets .swiper-pagination-bullet,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-bullets .swiper-pagination-bullet {
	display:inline-block;
	margin: 0 4px;
}
.slider_container.slider_pagination_pos_left .swiper-pagination-bullets,
.slider_container.slider_pagination_pos_right .swiper-pagination-bullets {
	left: 1em;
	top: 50%;
	bottom: auto;
	@include box(auto, auto);
	@include translateY(-50%);
}
.slider_container.slider_pagination_pos_right .swiper-pagination-bullets {
	right: 1em;
	left:auto;
}
.slider_container.slider_pagination_pos_left .swiper-pagination-bullets .swiper-pagination-bullet,
.slider_container.slider_pagination_pos_right .swiper-pagination-bullets .swiper-pagination-bullet {
	display: block;
	margin: 4px 0;
}


/* Pagination: Fraction */
.slider_wrap .swiper-pagination-fraction {
	&, &.swiper-pagination-current {
		@include transition-property(color);
	}
}
.slider_container .swiper-pagination-fraction,
.slider_outer .swiper-pagination-fraction {
	font-size:0.8667em;
	left: 0;
	top: auto;
	bottom: 0.5em;
	@include border-box;
}
.slider_outer.slider_outer_pagination_pos_left > .swiper-pagination-fraction,
.slider_container.slider_pagination_pos_left .swiper-pagination-fraction {
	text-align:left;
	padding-left:1em;
}
.slider_outer.slider_outer_pagination_pos_right > .swiper-pagination-fraction,
.slider_container.slider_pagination_pos_right .swiper-pagination-fraction {
	text-align:right;
	padding-right:1em;
}
.sc_item_slider {
	&:not(.slider_outer_controls_bottom) .swiper-pagination-fraction {
		position: static;
		margin-top: 1em;
	}
	&.slider_outer_pagination_pos_left > .swiper-pagination-fraction {
		padding-left: 0;
	}
	&.slider_outer_pagination_pos_right > .swiper-pagination-fraction {
		padding-right: 0;
	}

}
/*
.slider_outer.slider_outer_pagination_pos_left > .swiper-pagination-fraction,
.slider_outer.slider_outer_pagination_pos_right > .swiper-pagination-fraction {
	width: 7rem;
	bottom: 5rem;
}
.slider_outer.slider_outer_pagination_pos_right > .swiper-pagination-fraction {
	left: auto;
	right: 0;
}
*/
.slider_container .swiper-pagination-fraction > *,
.slider_outer .swiper-pagination-fraction > * {
	line-height:inherit;
	vertical-align:middle;
}
.slider_container .swiper-pagination-fraction > .swiper-pagination-current,
.slider_outer .swiper-pagination-fraction > .swiper-pagination-current {
	@include font(2em, 1.2em);
}

/* Pagination: Progress */
.slider_wrap .swiper-pagination-progressbar {
	&, &.swiper-pagination-progressbar-filled {
		@include transition-property(background-color);
	}
}
.slider_outer.slider_outer_pagination_pos_bottom_outside.slider_outer_pagination_progressbar:not(.sc_item_slider) .slider_pagination_wrap {
	margin-top: 0;
}
.slider_container.slider_pagination_pos_bottom .swiper-pagination-progressbar,
.slider_outer.slider_outer_pagination_pos_bottom .swiper-pagination-progressbar,
.slider_container.slider_pagination_pos_bottom_outside .swiper-pagination-progressbar,
.slider_outer.slider_outer_pagination_pos_bottom_outside .swiper-pagination-progressbar {
	left:0;
	width: 100%;
	height: 6px;
	top:auto;
	bottom:0;
}
.slider_container.slider_pagination_pos_right .swiper-pagination-progressbar,
.slider_outer.slider_outer_pagination_pos_right .swiper-pagination-progressbar {
	left: auto !important;
	right: 0;
	width: 6px;
	height: 100%;
	top: 0;
	bottom: auto;
}
.slider_container.slider_pagination_pos_left .swiper-pagination-progressbar,
.slider_outer.slider_outer_pagination_pos_left .swiper-pagination-progressbar {
	left: 0;
	right: auto !important;
	width: 6px;
	height: 100%;
	top: 0;
	bottom: auto;
}

/* Pagination in shortcodes */

/* To move pagination bullets below the items
.sc_item_slider.slider_outer_pagination_pos_bottom {
	padding-bottom: 2em;
}
*/
.sc_item_slider.slider_outer_pagination .swiper-pagination-bullet {
	border-color: #ddd;
}


/* Slider controls */
.sc_slider_controls .slider_prev, .sc_slider_controls .slider_next,
.slider_container .slider_prev, .slider_container .slider_next,
.slider_outer .slider_prev, .slider_outer_controls .slider_next {
	background-image:none !important;
	background-color:rgba(0,0,0,0.5);
	color: #fff;
	display:inline-block;
	vertical-align:middle;
	@include square(3em);
	@include border-round;
	@include transition-all;
}
.sc_slider_controls .slider_controls_wrap > a,
.slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_outer_controls_outside .slider_controls_wrap > a,
.slider_outer_controls_side .slider_controls_wrap > a,
.slider_outer_controls_top .slider_controls_wrap > a,
.slider_outer_controls_bottom .slider_controls_wrap > a {
	@include box(4.2em, 2.8em, 2.8em);
	@include border-sharp;
}
.sc_slider_controls .slider_prev:before, .sc_slider_controls .slider_next:before,
.slider_container .slider_prev:before, .slider_container .slider_next:before,
.slider_outer .slider_prev:before, .slider_outer .slider_next:before {
	margin:0;
	font-family: $trx_addons_icons;
}
.slider_controls_wrap {
	.swiper-button-prev:after,
	.swiper-container-rtl .swiper-button-next:after,
	.swiper-button-next:after,
	.swiper-container-rtl .swiper-button-prev:after {
		content: ' ';
		display: none;
	}
}
.sc_slider_controls,
.slider_container,
.slider_outer {
	.slider_prev.slider_arrow_default:before {
		content:'\e858';
	}
	.slider_next.slider_arrow_default:before {
		content:'\e859';
	}
	.slider_prev, .slider_next {
		&, &:before, & > span {
			@include transition-colors;
		}
	}
}

.sc_slider_controls .slider_prev.with_title,
.sc_slider_controls .slider_next.with_title {
	width: auto;
	padding: 0 1.5em;
}
.sc_slider_controls .slider_prev.with_title:before,
.sc_slider_controls .slider_next.with_title:before {
	display: none;
}

.sc_slider_controls .slider_prev,
.sc_slider_controls .slider_next {
	position:relative;
	top: auto;
	bottom: auto;
	left: auto;
	right: auto;
	margin: 0;
	display:inline-block;
	vertical-align:middle;
}
.sc_slider_controls .slider_next {
	order: 2;
}
.sc_slider_controls .slider_prev + .slider_next,
.sc_slider_controls .slider_prev + .slider_pagination_wrap,
.sc_slider_controls .slider_next + .slider_pagination_wrap {
	margin-left: 1em;
}

.sc_slider_controls .slider_controls_wrap {
	position:relative;
	@include border-box;
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(nowrap);
	@include flex-align-items(center);
}
.sc_slider_controls.sc_align_left .slider_controls_wrap {
	@include flex-justify-content(flex-start);
}
.sc_slider_controls.sc_align_center .slider_controls_wrap {
	@include flex-justify-content(center);
}
.sc_slider_controls.sc_align_right .slider_controls_wrap {
	@include flex-justify-content(flex-end);
}
.sc_slider_controls.slider_pagination_style_thumbs .slider_controls_wrap,
.sc_slider_controls.slider_pagination_style_progressbar .slider_controls_wrap {
	@include flex-justify-content(space-between);	
}
.sc_slider_controls.slider_pagination_style_thumbs .slider_controls_wrap .slider_pagination_wrap,
.sc_slider_controls.slider_pagination_style_progressbar .slider_controls_wrap .slider_pagination_wrap {
	@include flex-grow(2);
}

.sc_slider_controls .slider_controls_wrap .slider_pagination_wrap {
	@include flex;
	@include flex-direction(row);
	@include flex-wrap(wrap);
	@include flex-justify-content(center);
	@include flex-align-items(center);
	@include flex-grow(1);
	position:relative;
	text-align: center;
	height: 2.8em;
	@include transition-properties(width, background-color);
}

/* Images */
.sc_slider_controls .slider_pagination_button_wrap {
	display: inline-block;
	vertical-align: top;
	height: 100%;	
}
.sc_slider_controls .slider_pagination_button {
	display: block;
	height: 100%;
	margin-left: 1px;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: center;
	cursor: pointer;
	position: relative;
	overflow: hidden;
}
.sc_slider_controls .slider_pagination_button_wrap:first-child  .slider_pagination_button {
	margin-left: 0;
}
.sc_slider_controls .slider_pagination_button:before {
	content: ' ';
	@include bg-mask(#000);
	@include transition-properties(background-color,opacity);
	opacity: 0;
}
.sc_slider_controls .slider_pagination_button:hover:before,
.sc_slider_controls .slider_pagination_button_active:before {
	opacity: 0.2;
}

/* Progress */
.sc_slider_controls.slider_pagination_style_progressbar .slider_controls_wrap .slider_pagination_wrap {
	background-color:#f0f0f0;
	cursor: pointer;
	overflow: hidden;
}
.sc_slider_controls .slider_progress_bar {
	display:block;
	@include abs-lt;
	@include box(0, 100%);
	background-color:#ddd;
	@include transition-properties(background-color,width);
}

/* Bullets */
.sc_slider_controls.slider_pagination_style_bullets .slider_pagination_bullet {
	display: inline-block;
	vertical-align: top;
	border: 2px solid #f0f0f0;
	background-color: transparent;
	@include box(10px, 10px);
	@include bg-cover;
	opacity: 1;
	cursor: pointer;
	margin: 0 4px;
}

/* Fraction */
.sc_slider_controls.slider_pagination_style_fraction .slider_pagination_wrap > * {
	@include font(0.8667em, 1.7em);
}
.sc_slider_controls.slider_pagination_style_fraction .slider_pagination_wrap > .swiper-pagination-current {
	@include font(2em, 1.2em);
}


.slider_container.slider_controls_bottom .slider_controls_wrap,
.slider_outer .slider_controls_bottom .slider_controls_wrap {
	text-align:center;
	margin-top: 2em;
}
.slider_container.slider_controls_bottom .slider_prev, .slider_container.slider_controls_bottom .slider_next,
.slider_outer .slider_controls_bottom .slider_prev, .slider_outer .slider_controls_bottom .slider_next {
	position:static;
	display:inline-block;
	margin:0;
}
.slider_container.slider_controls_bottom .slider_next,
.slider_outer .slider_controls_bottom .slider_next {
	margin-left:1em;
}

.slider_container.slider_controls_side .slider_controls_wrap > .slider_prev,
.slider_outer_controls_side .slider_controls_wrap > .slider_prev {
	opacity: 0;
	margin-left: -6em;
	left: 0;
}
.slider_container.slider_controls_side .slider_controls_wrap > .slider_next,
.slider_outer_controls_side .slider_controls_wrap > .slider_next {
	opacity: 0;
	margin-right:-6em;
	right: 0;
}
.slider_container.slider_controls_side:hover .slider_controls_wrap > a,
.slider_outer_controls_side:hover .slider_controls_wrap > a {
	opacity: 1;
	margin-left:0;
	margin-right:0;
}

.slider_container.slider_controls_outside + .slider_controls_wrap > a,
.slider_outer_controls_outside .slider_controls_wrap > a {
	@include transition(color 0.3s ease, background-color 0.3s ease, opacity 0.3s ease 0.3s, margin 0.3s ease 0.3s);
}
.slider_container.slider_controls_outside + .slider_controls_wrap > .slider_prev,
.slider_outer_controls_outside .slider_controls_wrap > .slider_prev {
	opacity: 0;
	margin-left: -6em;
	left: -6em;
}
.slider_container.slider_controls_outside + .slider_controls_wrap > .slider_next,
.slider_outer_controls_outside .slider_controls_wrap > .slider_next {
	opacity: 0;
	margin-right:-6em;
	right: -6em;
}
.slider_container.slider_controls_outside:hover + .slider_controls_wrap > a,
.slider_container.slider_controls_outside + .slider_controls_wrap:hover > a,
.slider_container.slider_controls_outside + .slider_controls_wrap > a:hover,
.slider_outer_controls_outside:hover .slider_controls_wrap > a,
.slider_outer_controls_outside .slider_controls_wrap:hover > a,
.slider_outer_controls_outside .slider_controls_wrap > a:hover {
	opacity: 1;
	margin-left:0;
	margin-right:0;
}


/* Controls top and bottom */
.slider_outer_controls_top > .slider_controls_wrap {
	@include abs-rt(0, -3.3em, 11);
	@include box(auto, 3em);
}
.sc_item_slider.slider_outer_controls_top > .slider_controls_wrap {
	top: -5em;
}
.slider_outer_controls_bottom > .slider_controls_wrap {
	position:relative;
	display: block;
	text-align:center;
	margin-top: 1em;
}
.slider_outer_controls_top > .slider_controls_wrap > a,
.slider_outer_controls_bottom > .slider_controls_wrap > a {
	position:relative;
	top: auto;
	bottom: auto;
	left: auto;
	right: auto;
	margin: 0;
	display:inline-block;
	vertical-align:middle;
}
.slider_outer_controls_top > .slider_controls_wrap > a+a,
.slider_outer_controls_bottom > .slider_controls_wrap > a+a {
	margin-left: 0.5em;
}


/* Video in the slider */
.slider_container .trx_addons_video_player.with_cover {
	@include abs-cover;
}


/* Style 'Modern' */
.slider_style_modern {
	padding: 0 7rem;
}
.slider_style_modern.slider_outer_controls_side .slider_controls_wrap > a {
	position:absolute;
	top: 3rem;
	bottom: 3rem;
	@include box(7rem, auto, 1.2em);
	margin:0;
	background-color: #333;
	color: #fff;
	@include border-sharp;
}
.slider_style_modern.slider_outer_controls_side.slider_outer_pagination_pos_bottom_outside .slider_controls_wrap > a {
	bottom: 6rem;
}
.slider_style_modern.slider_outer_controls_side.slider_outer_titles_outside .slider_controls_wrap > a {
	bottom: 8rem;
}
.slider_style_modern.slider_outer_controls_side.slider_outer_titles_outside.slider_outer_pagination_pos_bottom_outside .slider_controls_wrap > a {
	bottom: 11rem;
}
.slider_style_modern .slider_controls_label,
.slider_style_modern.slider_outer_controls_side .slider_controls_wrap > a:before {
	display:block;
	text-align:center;
	max-width: 80%;
	@include abs-lt(50%, 45%, '');
	@include translate(-50%, -50%);
}
.slider_style_modern.slider_outer_controls_side .slider_controls_wrap > a:before {
	top: 58%;
}
.slider_style_modern .slider_controls_label > span {
	display: block;
}
.slider_style_modern .slider_controls_label span:first-child {
	font-style: italic;
	letter-spacing: 0;
}
.sc_slider_controller .slider_outer.slider_outer_controls_side .slider_controls_wrap > a,
.slider_style_modern .slider_container.slider_controls_side .slider_controls_wrap > a,
.slider_style_modern.slider_outer_controls_side .slider_controls_wrap > a {
	opacity: 1;
}
.slider_style_modern.slider_outer_titles_outside > .slider_pagination_wrap {
	display:none;
}


/* Slider + Controller container */
:root {
	--sc-slider-controller-height: 100px;
}
.sc_slider_controller_horizontal,
.slider_outer_wrap_controller_pos_bottom .sc_slider_controller {
	.slider_controller_container {
		height: var(--sc-slider-controller-height);
	}
	.sc_slider_controller_item_image {
		height: calc( var(--sc-slider-controller-height) - 2em );
	}
}
.sc_slider_controller_vertical,
.slider_outer_wrap_controller_pos_left .sc_slider_controller,
.slider_outer_wrap_controller_pos_right .sc_slider_controller {
	.sc_slider_controller_item_image {
		max-height: 7em;
	}
}

.slider_outer_wrap {
	@include border-box;
	position: relative;
	
	&.slider_outer_wrap_controller_pos_left {
		padding-left: 33.3333%;
	
		.sc_slider_controller {
			@include abs-lt;
			@include box( 33.3333%, 100%);
			padding-right: 1px;
		}
	}

	&.slider_outer_wrap_controller_pos_right {
		padding-right: 33.3333%;

		.sc_slider_controller {
			@include abs-rt;
			@include box( 33.3333%, 100%);
			padding-left: 1px;
		}
	}

	&.slider_outer_wrap_controller_pos_bottom {
		.sc_slider_controller {
			.slider-slide {
				padding: 1em;
			}
		}
	}

	.sc_slider_controller {
		.slider-slide {
			@include flex;
			@include flex-direction(row);
			@include flex-justify-content(flex-start);
			@include flex-align-items(center);
			overflow: hidden;
			background-color: #fff;
			padding: 1em 0.5em 1em 2em;
			@include border-box;
			@include transition-colors;
		}
		.slider-slide.swiper-slide-active {
			background-color: #f7f7f7;
		}
		.sc_slider_controller_item {
			@include flex;
			@include flex-direction(row);
			@include flex-justify-content(flex-start);
			@include flex-align-items(center);
			@include flex-basis(100%);
		}
		.sc_slider_controller_item_image {
			@include flex-shrink(0);
		}
		.sc_slider_controller_item_image + .sc_slider_controller_item_info,
		.sc_slider_controller_item_image ~ .sc_slider_controller_item_info {
			padding-left: 2em;
			@include flex-grow(1);
		}
		.sc_slider_controller_item_info_number,
		.sc_slider_controller_item_info_image,
		.sc_slider_controller_item_info_title,
		.sc_slider_controller_item_info_date,
		.sc_slider_controller_item_info_cats {
			@include transition-colors;
		}
		.sc_slider_controller_item_info_title {
			margin: 0;
			@include font(1.15em, 1.4em);
		}
		.sc_slider_controller_item_info_date {
			@include font(0.9286em, 1.5em);
			color: #888;
		}
		.sc_slider_controller_item_info_number {
			margin-right: 0.3em;
		}
	}
}


/* Slider Controller */
.sc_slider_controller {
	@include border-box;

	.slider_prev, .slider_next {
		&, &:before {
			@include transition-colors;
		}
	}
}
.sc_slider_controller .slider-slide {
	cursor: pointer;
	min-height:50px;
}
.sc_slider_controller_horizontal {
	padding-top: 1px;

	.slider_outer_pagination_pos_bottom_outside + &,
	.slider_outer_controls_bottom + & {
		margin-top: 1em;
	}
}
.sc_slider_controller_horizontal[data-controls="1"] {
	padding-left: 4em;
	padding-right: 4em;
}
.sc_slider_controller_vertical[data-controls="1"] {
	padding-top: 3em;
	padding-bottom: 3em;
}
.sc_slider_controller .slider_outer_controls_side .slider_controls_wrap > a {
	margin:0;
	@include transform-none;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > a {
	top:0;
	bottom:0;
	@include box(4em, auto);
}
.sc_slider_controller_vertical .slider_outer_controls_side .slider_controls_wrap > a {
	left:0;
	right:0;
	@include box(auto, 3em);
}
.sc_slider_controller .slider_outer_controls_side .slider_controls_wrap > a:before {
	display:block;
	@include box(auto, 1em, 1em !important);
	@include abs-cc('');
}
.sc_slider_controller .slider_outer_controls_side .slider_controls_wrap > a {
	@include border-sharp;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > .slider_prev {
	left:-4em;
	right: auto;
}
.sc_slider_controller_horizontal .slider_outer_controls_side .slider_controls_wrap > .slider_next {
	right:-4em;
	left: auto;
}
.sc_slider_controller_vertical .slider_outer_controls_side .slider_controls_wrap > .slider_prev {
	top:-3em;
	bottom: auto;
}
.sc_slider_controller_vertical .slider_outer_controls_side .slider_controls_wrap > .slider_next {
	bottom:-3em;
	top: auto;
}
.sc_slider_controller_vertical .slider_outer_controls_side .slider_controls_wrap > .slider_prev.slider_arrow_default:before {
	content:'\e85a';
	font-family: $trx_addons_icons;
}
.sc_slider_controller_vertical .slider_outer_controls_side .slider_controls_wrap > .slider_next.slider_arrow_default:before {
	content:'\e857';
	font-family: $trx_addons_icons;
}

.sc_slider_controller_info {
	display:block;
	text-align:left;
	letter-spacing:0;
	@include font(1.3333em, 1.2em, normal, normal);
	@include abs-cc('');
	width: 85%;
}
.sc_slider_controller_info_number,
.sc_slider_controller_info_image,
.sc_slider_controller_info_title,
.sc_slider_controller_info_date,
.sc_slider_controller_info_cats {
	@include transition-colors;
}

.sc_slider_controller_info_number {
	// display:inline-block;
	// vertical-align: middle;
	color: #eee;
	margin-right: 0.4em;
}
.sc_slider_controller_info_title {
	// display:inline-block;
	// vertical-align: middle;
	// max-width: 80%;
	color: #fff;
}

.sc_slider_controller_horizontal .slider-slide.swiper-slide-active:after {
	content: ' ';
	@include abs-lt(0, 0, 2);
	@include box(100%, 3px);
	background-color: #efa758;
}

.sc_slider_controller_thumbs .slider-slide:before,
.slider_outer_wrap .sc_slider_controller .slider-slide-bg:before {
	content: ' ';
	@include bg-mask(#000, 0.5, 1);
	@include transition-property(background-color, .5s);
}
.sc_slider_controller_thumbs .slider-slide.swiper-slide-active:before,
.slider_outer_wrap .sc_slider_controller .slider-slide-bg.swiper-slide-active:before {
	background-color: transparent;
}

.sc_slider_controller_thumbs .sc_slider_controller_info {
	@include font(1.2em, 1.2em);
	display:none;
}
.sc_slider_controller_thumbs .sc_slider_controller_info_number {
	color: #ccc;
}
.sc_slider_controller_thumbs .sc_slider_controller_info_title {
	color: #fff;
}

.sc_slider_controller_titles .sc_slider_controller_info {
	text-transform: uppercase;
}
.sc_slider_controller_titles .slider-slide {
	background-color:#f0f0f0;
}
.sc_slider_controller_titles .slider-slide:before {
	content: ' ';
	@include abs-pos(0, 0, 0, auto);
	width: 1px;
	background-color: #ddd;
}
.sc_slider_controller_titles .slider-slide.swiper-slide-active:before {
	display:none;
}
.sc_slider_controller_titles .slider-slide.swiper-slide-active {
	margin-top:0;
	padding-top:0;
	background-color:#fff;
}




/* Slider ElastiStack
------------------------------------------------------------ */
/*
.slider_elastistack {
	@include transition(transform 0.1s cubic-bezier(0.6, 0, 0.5, 1));
}
*/
.slider_elastistack ul[class*="stack__"] {
	position: relative;
	margin: 0 auto;
	padding: 0;
	list-style: none;
}
.slider_elastistack ul[class*="stack__"] li {
	position: absolute;
	width: 100%;
	opacity: 0;
	padding:0;
}
.slider_elastistack ul[class*="stack__"] li:before {
	display: none;
}

.slider_elastistack ul.stack__images {
	width: 100%;
	z-index: 10;
	@include perspective(1000px);
	@include perspective-origin(50% -50%);
}
.slider_elastistack .stack__images li {
	top: 0;
	z-index: 1;
	@include translate3d(0,0,-180px);
	@include preserve3d;
}

.slider_elastistack .stack__images li img {
	display: block;
	width: 100%;
	pointer-events: none;
}

.slider_elastistack .stack__images li:active {
	cursor: -webkit-grabbing;
	cursor: grabbing;
}

.slider_elastistack .stack__images li.animate {
	@include transition-all(0.3s, ease-out);
}
.slider_elastistack .stack__images li.move-back {
	@include transition-timing(0.175, 0.885, 0.470, 1.515);
}

/* Titles outside in ElastiStack */
.slider_elastistack_outer.slider_outer_controls {
	padding-bottom: 4em;
}
.slider_elastistack_outer.slider_outer_titles_outside.slider_outer_controls {
	padding-bottom: 13em;
}
.slider_elastistack_outer.slider_outer_controls .slider_controls_wrap {
	@include abs-cb;
}
.slider_elastistack.slider_controls > .slider_controls_wrap {
	bottom: -4em;
}

.slider_elastistack_outer.slider_outer_controls .slider_controls_wrap > .slider_prev {
	display:none;
}
.slider_elastistack_outer.slider_outer_controls .slider_controls_wrap > .slider_next {
	position: static;
	margin:0;
	left: auto;
	right: auto;
	opacity:1;	
}
.slider_elastistack_outer.slider_outer_controls .slider_controls_wrap > .slider_next:before {
	content: '\e857';
}
